@@ -97,7 +97,7 @@ class ReqsTestGenerator(object):
             stripped_header = regex_rfc5424.group(3)
             return stripped_header
         regex_rfc3164 = re.search(
-            r"([A-Z][a-z][a-z]\s{1,2}\d{1,2}\s\d{2}[:]\d{2}[:]\d{2})\s+([\w][\w\d\.@-]*)\s(.*)$",
+            r"([A-Z][a-z][a-z]\s{1,2}\d{1,2}\s\d{2}[:]\d{2}[:]\d{2})\s+([\w][\w\d\.@-]*)\s\w*:?(.*)$",
             raw_event,
         )
         if regex_rfc3164:
